@@ -18,27 +18,30 @@ class SprintScheduleStore:
         if content is None:
             raise ValueError("The content is invalid.")
 
-        raw_data = json.loads(content)
+        try:
+            raw_data = json.loads(content)
 
-        priority = 0
-        sprints = []
-        for item in raw_data:
-            for key, value in item.items():
-                if key.lower() in "priority":
-                    priority = value
-                if key.lower() in "sprints":
-                    for sprint in value:
-                        if len(sprint) > 0:
-                            sprints.append(sprint)
-
-            for sprint in sprints:
-                self.store.append((sprint, priority))
-            sprints.clear()
             priority = 0
+            sprints = []
+            for item in raw_data:
+                for key, value in item.items():
+                    if key.lower() in "priority":
+                        priority = value
+                    if key.lower() in "sprints":
+                        for sprint in value:
+                            if len(sprint) > 0:
+                                sprints.append(sprint)
+
+                for sprint in sprints:
+                    self.store.append((sprint, priority))
+                sprints.clear()
+                priority = 0
+        except Exception:
+            raise ValueError("The JSON file structure is invalid.")
 
     def load_file(self, file: str):
         """
-        Load json file to generate the excel defination
+        Load json file to generate the excel definition
 
         :param file:
             JSON file location
@@ -51,8 +54,10 @@ class SprintScheduleStore:
             raise ValueError(f"The file is not exist. File: {file}")
 
         with open(file=file, mode="r") as schedule_file:
-            self.load(schedule_file.read())
-            schedule_file.close()
+            try:
+                self.load(schedule_file.read())
+            finally:
+                schedule_file.close()
 
     def get_priority(self, sprint: str) -> int:
         for item in self.store:
